==> mysql-workbench-community-6.3.7-src.tar.gz: mysql-workbench-community-6.3.7-src/frontend/mac/components/MCollectionViewItem.m <==
/*
 * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#import "MCollectionViewItem.h"
#import "MCollectionViewItemView.h"

@implementation MCollectionViewItem


- (id)copy
{
  id other = [super copy];
  [other view].menu = self.view.menu;
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)[other view];
  itemView.owner = other;
  return other;
}


- (void)setView: (NSView*)view
{
  [super setView: view];
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)view;
  itemView.owner = self;
}


- (void)setSelected:(BOOL)flag 
{
  [super setSelected:flag];
  
  MCollectionViewItemView* itemView= (MCollectionViewItemView*)[self view];
  if ([itemView isKindOfClass:[MCollectionViewItemView class]]) 
  {
    [itemView setSelected:flag];
    [itemView setNeedsDisplay:YES];
  }
}

@end

==> mysql-workbench-community-6.3.10-src.tar.gz: mysql-workbench-community-6.3.10-src/frontend/mac/components/MCollectionViewItem.m <==
/*
 * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#import "MCollectionViewItem.h"
#import "MCollectionViewItemView.h"

@implementation MCollectionViewItem


- (id)copy
{
  id other = [super copy];
  [other view].menu = self.view.menu;
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)[other view];
  itemView.owner = other;
  return other;
}


- (void)setView: (NSView*)view
{
  super.view = view;
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)view;
  itemView.owner = self;
}


- (void)setSelected:(BOOL)flag 
{
  super.selected = flag;
  
  MCollectionViewItemView* itemView= (MCollectionViewItemView*)self.view;
  if ([itemView isKindOfClass:[MCollectionViewItemView class]]) 
  {
    itemView.selected = flag;
    [itemView setNeedsDisplay:YES];
  }
}

@end
